package controllers

import (
	"github.com/rdlucklib/rdluck_tools/paging"
	"hongze/hongze_cygx/models"
	"hongze/hongze_cygx/services"
	"hongze/hongze_cygx/utils"
	"html"
	"strings"
)

type HomeController struct {
	BaseAuthController
}

// @Title 首页列表接口
// @Description 首页列表接口
// @Param   PageSize   query   int  true       "每页数据条数"
// @Param   CurrentIndex   query   int  true       "当前页页码，从1开始"
// @Param   ChartPermissionId   query   int  true       "品类id，最新传0"
// @Success 200 {object} models.HomeListResp
// @router /list [get]
func (this *HomeController) ListHome() {
	br := new(models.BaseResponse).Init()
	defer func() {
		this.Data["json"] = br
		this.ServeJSON()
	}()
	user := this.User
	if user == nil {
		br.Msg = "请登录"
		br.ErrMsg = "请登录，用户信息为空"
		br.Ret = 408
		return
	}
	pageSize, _ := this.GetInt("PageSize")
	currentIndex, _ := this.GetInt("CurrentIndex")
	chartPermissionId, _ := this.GetInt("ChartPermissionId")

	var startSize int
	if pageSize <= 0 {
		pageSize = utils.PageSize20
	}
	if currentIndex <= 0 {
		currentIndex = 1
	}
	startSize = paging.StartIndex(currentIndex, pageSize)

	var condition string
	var pars []interface{}
	var total int
	resp := new(models.HomeListResp)
	page := paging.GetPaging(currentIndex, pageSize, total)
	resp.HaveResearch = true
	userType, _, err := services.GetUserType(user.CompanyId)
	if err != nil {
		br.Msg = "获取信息失败"
		br.ErrMsg = "获取用户信息失败,Err:" + err.Error()
		return
	}
	condition += ` AND is_summary = 1  `
	if chartPermissionId > 0 {
		categoryId, err := models.GetCategoryId(chartPermissionId)
		if err != nil && err.Error() != utils.ErrNoRow() {
			br.Msg = "获取信息失败"
			br.ErrMsg = "获取分类权限信息失败，Err:" + err.Error()
			return
		}
		categoryinfo, err := models.GetChartPermissionById(chartPermissionId)
		if err != nil {
			br.Msg = "获取信息失败"
			br.ErrMsg = "获取信息失败,Err:" + err.Error()
			return
		}
		if userType == 1 && categoryinfo.PermissionName == "研选" {
			resp.HaveResearch = false
			resp.Paging = page
			br.Ret = 200
			br.Success = true
			br.Msg = "获取成功"
			br.Data = resp
			return
		}
		page = paging.GetPaging(currentIndex, pageSize, total)
		if categoryId != "" {
			condition += ` AND category_id IN(` + categoryId + `)`
			condition += ` OR ( category_name  LIKE '%` + categoryinfo.PermissionName + `%' AND publish_status = 1 AND is_summary = 1 )`
		} else {
			condition += ` AND  category_name   LIKE '%` + categoryinfo.PermissionName + `%'`
		}
	}
	//永续客户无法查看研选分类的内容
	if userType == 1 {
		condition += ` AND  category_name  NOT LIKE '%研选` + `%'`
	}
	total, err = models.GetHomeCount(condition, pars)
	if err != nil {
		br.Msg = "获取信息失败"
		br.Msg = "获取帖子总数失败，Err:" + err.Error()
		return
	}
	page = paging.GetPaging(currentIndex, pageSize, total)
	list, err := models.GetHomeList(condition, pars, startSize, pageSize)
	if err != nil {
		br.Msg = "获取信息失败"
		br.Msg = "获取帖子数据失败，Err:" + err.Error()
		return
	}
	lenList := len(list)
	for i := 0; i < lenList; i++ {
		item := list[i]
		//如果文章一开始的内容是图片，优先展示第一张图片
		imgurl, _ := services.FixArticleImgUrl(html.UnescapeString(list[i].Body))
		newBody, _ := services.GetReportContentTextSub(item.Body)
		list[i].Body = newBody
		if imgurl != "" {
			if len(newBody) > 0 {
				strnum := strings.Index((list[i].Body), imgurl)
				newBody = newBody[0:3]
				strnum2 := strings.Index((list[i].Body), newBody)
				if strnum < strnum2 {
					list[i].BodyHtml = `<p><img src="` + imgurl + `" class="fr-fic fr-dib"></p>`
				}
			} else {
				list[i].BodyHtml = `<p><img src="` + imgurl + `" class="fr-fic fr-dib"></p>`
			}
		}
		list[i].PublishDate = utils.StrTimeToTime(item.PublishDate).Format(utils.FormatDateTimeNoSecond) //时间字符串格式转时间格式
		if strings.Contains(item.CategoryName, "研选") {
			list[i].IsResearch = true
		}
		if item.Pv > 999 {
			list[i].Pv = 999
		}
		list[i].ImgUrlPc = "https://hongze.oss-cn-shanghai.aliyuncs.com/static/images/202112/20211206/UvMadc63MLZY6rnQZQgGZAFXkqwf.png"
	}
	resp.List = list
	resp.Paging = page
	br.Ret = 200
	br.Success = true
	br.Msg = "获取成功"
	br.Data = resp
}
