package models

import (
	"github.com/rdlucklib/rdluck_tools/orm"
	"github.com/rdlucklib/rdluck_tools/paging"
	"time"
)

type Activity struct {
	ActivityTypeId   int    `description:"活动类型id"`
	ActivityTypeName string `description:"活动名称"`
	TemplateP        string `description:"活动模板，带P标签"`
	Template         string `description:"活动模板"`
	ShowType         string `description:"人数限制类型，1不展示限制，2可选限制，3强制限制"`
}
type ActivityIdRep struct {
	ActivityId int `description:"活动id"`
}

type ActivitySingnupRep struct {
	ActivityId int `description:"活动id"`
	SignupType int `description:"报名方式，1预约外呼，2我要报名"`
}

type ActivityCcustomerType struct {
	CustomerTypeId int    `description:"活动类型id"`
	CustomerName   string `description:"活动名称"`
}

type ActivityCcustomerTypeList struct {
	List []*ActivityCcustomerType
}

//列表
func GetActivityCcustomerTypeList() (items []*ActivityCcustomerType, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_customer_type ORDER BY sort DESC`
	_, err = o.Raw(sql).QueryRows(&items)
	return
}

//活动添加、修改入参
type ActivityRep struct {
	ActivityTypeId    int    `description:"活动类型id"`
	ChartPermissionId int    `description:"行业id"`
	Body              string `description:"内容"`
	LimitPeopleNum    int    `description:"限制的人数数量"`
	CustomerTypeIds   string `description:"活动可见的客户类型，多个ID用 , 隔开"`
	ActivityId        int    `description:"活动ID 等于0新增活动，大于0修改活动"`
	DoType            int    `description:"操作类型 0，保存 、1，发布"`
}

//活动详情
type ActivityDetail struct {
	ActivityId              int    `orm:"column(activity_id);pk";description:"活动ID "`
	ActivityTypeId          int    `description:"活动类型id"`
	ActivityTypeName        string `description:"活动类型名称"`
	ChartPermissionId       int    `description:"行业id"`
	ChartPermissionName     string `description:"行业名称"`
	ChartPermissionNames    string `description:"行业名称辅助字段，区分研选子分类"`
	Body                    string `description:"内容"`
	CreateTime              string `description:"创建时间"`
	IsLimitPeople           int    `description:"是否限制人数 1是，0否"`
	LimitPeopleNum          int    `description:"限制的人数数量"`
	LastUpdatedTime         string `description:"更新时间"`
	ActivityTime            string `description:"活动时间"`
	ActivityTimeText        string `description:"活动时间带文字"`
	DistinguishedGuest      string `description:"嘉宾"`
	Host                    string `description:"主持人"`
	Speaker                 string `description:"主讲人"`
	MainlandTell            string `description:"大陆拨入号"`
	HongKongTell            string `description:"香港拨入号"`
	TaiwanTell              string `description:"台湾拨入号"`
	AmericaTell             string `description:"美国拨入号"`
	ParticipationCode       string `description:"参会密码"`
	Theme                   string `description:"主题"`
	Expert                  string `description:"专家"`
	ActivityName            string `description:"活动名称"`
	OnlineParticipation     string `description:"网络参会"`
	ReportLink              string `description:"报告链接"`
	City                    string `description:"城市"`
	Address                 string `description:"活动地址"`
	Highlights              string `description:"活动亮点"`
	Remarks                 string `description:"备注"`
	ShowType                string `description:"人数限制类型，1不展示限制，2可选限制，3强制限制"`
	IsSignup                int    `description:"是否已报名 1是 ，0 否"`
	SignupNum               int    `description:"已报名人数"`
	SignupType              int    `description:"报名方式，1预约外呼，2自主拨入，3我要报名"`
	ActiveState             string `description:"活动进行状态 未开始：1、进行中2、已结束3"`
	IsCancelMeetingReminder int    `description:"是否取消会议提醒 1展示取消会议提醒 ，0展示会议提醒"`
	ArticleId               int    `description:"报告id（报告链接跳转使用）"`
	CustomerTypeIds         string `description:"活动可见的客户类型，多个ID用 , 隔开"`
	IsShowSustainable       bool   `description:"是否展示限免标签"`
	Description             string `description:"研选内容说明"`
	IsResearch              bool   `description:"是否属于研选"`
	LinkParticipants        string `description:"链接参会"`
	AppAttendance           string `description:"App参会"`
	ConferencePassword      string `description:"会议密码"`
}

type CygxActivityResp struct {
	HaqveJurisdiction bool   `description:"是否有权限"`
	OperationMode     string `description:"操作方式 Apply:立即申请、Call:拨号 为空则为有权限"`
	HasPermission     int    `description:"操作方式，1:有该行业权限,正常展示，2：无该行业权限，3：潜在客户，未提交过申请，4：潜在客户,已提交过申请"`
	PopupMsg          string `description:"权限弹窗信息"`
	MsgType           string `description:"Type ： 类型 , Industry ： 行业"`
	SellerMobile      string `description:"销售电话"`
	SellerName        string `description:"销售姓名"`
	Detail            *ActivityDetail
}

//通过纪要ID获取活动详情
func GetAddActivityInfoById(ActivityId int) (item *ActivityDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_activity  WHERE activity_id=? AND publish_status = 1 `
	err = o.Raw(sql, ActivityId).QueryRow(&item)
	return
}

//通过纪要ID获取活动详情
func GetAddActivityInfoByIdShow(uid, ActivityId int) (item *ActivityDetail, err error) {
	o := orm.NewOrm()
	sql := `SELECT *,( SELECT COUNT( 1 ) FROM cygx_activity_signup AS s WHERE s.activity_id = a.activity_id AND s.user_id = ?   AND s.is_cancel = 0  AND s.do_fail_type = 0) AS is_signup,
			( SELECT COUNT( DISTINCT user_id ) FROM cygx_activity_signup AS s WHERE s.activity_id = a.activity_id  AND s.is_cancel = 0 AND s.do_fail_type = 0) AS signup_num,
			( SELECT COUNT( 1 ) FROM cygx_activity_meeting_reminder AS m WHERE m.activity_id = a.activity_id AND m.user_id = ?  AND m.is_cancel = 0 ) AS is_cancel_meeting_reminder
			FROM cygx_activity AS a  WHERE activity_id=? AND publish_status = 1 `
	err = o.Raw(sql, uid, uid, ActivityId).QueryRow(&item)
	return
}

//活动详情
type CygxActivityList struct {
	ActivityId              int    `orm:"column(activity_id);pk";description:"活动ID 等于0新增活动，大于0修改活动"`
	ActivityTypeId          int    `description:"活动类型id"`
	ActivityName            string `description:"活动名称"`
	ActivityTypeName        string `description:"活动类型名称"`
	Speaker                 string `description:"主讲人"`
	SignupType              int    `description:"报名方式，1预约外呼，2我要报名"`
	ChartPermissionId       int    `description:"行业id"`
	ChartPermissionName     string `description:"行业名称"`
	IsLimitPeople           int    `description:"是否限制人数 1是，0否"`
	LimitPeopleNum          int    `description:"限制的人数数量"`
	ActivityTime            string `description:"活动时间"`
	ActivityTimeText        string `description:"活动时间带文字"`
	City                    string `description:"城市"`
	Address                 string `description:"活动地址"`
	DistinguishedGuest      string `description:"嘉宾"`
	Expert                  string `description:"专家"`
	IsSignup                int    `description:"是否已报名 1是 ，0 否"`
	SignupNum               int    `description:"已报名人数"`
	ActiveState             string `description:"活动进行状态 未开始：1、进行中2、已结束3"`
	IsCancelMeetingReminder int    `description:"是否取消会议提醒 1展示取消会议提醒 ，0展示会议提醒"`
	IsBrackets              int    `description:"是否有方括号 1是 ，0 否"`
	Label                   string `description:"主题标签"`
	IsShowSustainable       bool   `description:"是否展示限免标签"`
	ImgUrl                  string `description:"图片链接"`
	ActivityType            int    `description:"活动线上线下类型 1线上，0 线下"`
}

type GetCygxActivityListRep struct {
	Paging *paging.PagingItem `description:"分页数据"`
	List   []*CygxActivityList
	Label  string `description:"主题"`
	ImgUrl string `description:"图片路径"`
}

//列表
func GetActivityListAll(condition string, pars []interface{}, uid, startSize, pageSize int) (items []*CygxActivityList, err error) {
	o := orm.NewOrm()
	sql := `SELECT art.* ,t.activity_type,c.image_url as  img_url,
		( SELECT COUNT( 1 ) FROM cygx_activity_signup AS s WHERE s.activity_id = art.activity_id AND s.user_id = ?   AND s.is_cancel = 0  AND s.do_fail_type = 0) AS is_signup,
		( SELECT COUNT( DISTINCT user_id ) FROM cygx_activity_signup AS s WHERE s.activity_id = art.activity_id   AND s.is_cancel = 0  AND s.do_fail_type = 0) AS signup_num,
		( SELECT COUNT( 1 ) FROM cygx_activity_meeting_reminder AS m WHERE m.activity_id = art.activity_id AND m.user_id = ?  AND m.is_cancel = 0  ) AS is_cancel_meeting_reminder
		FROM cygx_activity as art
		INNER JOIN cygx_activity_type  as t ON t.activity_type_id = art.activity_type_id
		INNER JOIN  chart_permission  AS c ON c.chart_permission_id = art.chart_permission_id 
		WHERE 1= 1 `
	if condition != "" {
		sql += condition
	}
	sql += ` LIMIT ?,?`
	_, err = o.Raw(sql, pars, uid, uid, startSize, pageSize).QueryRows(&items)
	return
}

//列表
func GetActivityListByDateTime(startDate, endDate string) (items []*CygxActivityList, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_activity WHERE activity_time > '` + startDate + `' AND activity_time < '` + endDate + `' `
	_, err = o.Raw(sql).QueryRows(&items)
	return
}

//获取数量
func GetActivityCount(condition string, pars []interface{}) (count int, err error) {
	sqlCount := ` SELECT COUNT(1) AS count  FROM cygx_activity as art WHERE 1= 1  `
	if condition != "" {
		sqlCount += condition
	}
	o := orm.NewOrm()
	err = o.Raw(sqlCount, pars).QueryRow(&count)
	return
}

//获取我的日程数量
func GetScheduleCount(condition string, uid int) (count int, err error) {
	o := orm.NewOrm()
	sqlCount := `SELECT COUNT( 1 ) AS count 
				FROM cygx_my_schedule AS m
				INNER JOIN cygx_activity AS art ON art.activity_id = m.activity_id 
				WHERE
				user_id = ?`
	if condition != "" {
		sqlCount += condition
	}
	err = o.Raw(sqlCount, uid).QueryRow(&count)
	return
}

//我的日程列表
func GetScheduleList(condition string, pars []interface{}, uid, startSize, pageSize int) (items []*CygxActivityList, err error) {
	o := orm.NewOrm()
	sql := `SELECT art.*,t.activity_type,c.image_url as  img_url,
			( SELECT COUNT( 1 ) FROM cygx_activity_signup AS s WHERE s.activity_id = art.activity_id AND s.user_id = ? AND s.is_cancel = 0 AND s.do_fail_type = 0) AS is_signup,
            ( SELECT COUNT( DISTINCT user_id ) FROM cygx_activity_signup AS s WHERE s.activity_id = art.activity_id AND  s.is_cancel = 0  AND s.do_fail_type = 0) AS signup_num ,
			( SELECT COUNT( 1 ) FROM cygx_activity_meeting_reminder AS m WHERE m.activity_id = art.activity_id AND m.is_cancel = 0 AND m.user_id = ? ) AS is_cancel_meeting_reminder
            FROM cygx_activity AS art
			INNER JOIN cygx_my_schedule as my ON my.activity_id = art.activity_id 
			INNER JOIN cygx_activity_type  as t ON t.activity_type_id = art.activity_type_id
			INNER JOIN  chart_permission  AS c ON c.chart_permission_id = art.chart_permission_id 
            WHERE 1=1 AND my.user_id = ? `
	if condition != "" {
		sql += condition
	}
	sql += ` ORDER BY art.active_state ASC,art.activity_time ASC  LIMIT ?,?`
	_, err = o.Raw(sql, pars, uid, uid, uid, startSize, pageSize).QueryRows(&items)
	return
}

//获取数量
func GetActivityCountById(activityId int) (count int, err error) {
	o := orm.NewOrm()
	sqlCount := `SELECT COUNT(1) AS count  FROM cygx_activity WHERE activity_id = ?`
	err = o.Raw(sqlCount, activityId).QueryRow(&count)
	return
}

//删除数据
func DeleteActivity(activityId int) (err error) {
	o := orm.NewOrm()
	sql := ` DELETE FROM cygx_activity WHERE activity_id = ?`
	_, err = o.Raw(sql, activityId).Exec()
	return
}

//修改活动状态至进行中
func UpdateActivitySattusToHaveInHand() (err error) {
	o := orm.NewOrm()
	resultTime_30 := time.Now().Add(-time.Minute * 30).Format("2006-01-02 15:04:05")
	resultTime_60 := time.Now().Add(-time.Minute * 60).Format("2006-01-02 15:04:05")
	var sqlOr string
	var condition string
	condition += ` AND activity_time < NOW()`
	sqlOr = condition
	condition += ` AND (activity_type_id IN ( 1, 2, 3 ) AND  activity_time > ` + "'" + resultTime_30 + "'" + ")"
	condition += ` OR(activity_type_id IN ( 4, 5, 6 ) AND  activity_time > ` + "'" + resultTime_60 + "'" + sqlOr + ")"
	msql := " UPDATE cygx_activity SET active_state = 2 WHERE 1 = 1 " + condition
	_, err = o.Raw(msql).Exec()
	return
}

//修改活动状态至已结束
func UpdateActivitySattusToComplete() (err error) {
	o := orm.NewOrm()
	resultTime_30 := time.Now().Add(-time.Minute * 30).Format("2006-01-02 15:04:05")
	resultTime_60 := time.Now().Add(-time.Minute * 60).Format("2006-01-02 15:04:05")
	//var sqlOr string
	var condition string
	//condition += ` AND activity_time < NOW()`
	//sqlOr = condition
	condition += ` AND (activity_type_id IN ( 1, 2, 3 ) AND  activity_time < ` + "'" + resultTime_30 + "'" + ")"
	condition += ` OR(activity_type_id IN ( 4, 5, 6 ) AND  activity_time < ` + "'" + resultTime_60 + "'" + ")"
	msql := " UPDATE cygx_activity SET active_state = 3 WHERE 1 = 1 " + condition
	_, err = o.Raw(msql).Exec()
	return
}

//活动详情
type WxMsgCygxActivityList struct {
	Id                      int    `description:"报名ID"`
	ActivityId              int    `description:"活动ID 等于0新增活动，大于0修改活动"`
	ActivityTypeId          int    `description:"活动类型id"`
	ActivityName            string `description:"活动名称"`
	ActivityTypeName        string `description:"活动类型名称"`
	Speaker                 string `description:"主讲人"`
	SignupType              int    `description:"报名方式，1预约外呼，2我要报名"`
	ChartPermissionId       int    `description:"行业id"`
	ChartPermissionName     string `description:"行业名称"`
	IsLimitPeople           int    `description:"是否限制人数 1是，0否"`
	LimitPeopleNum          int    `description:"限制的人数数量"`
	ActivityTime            string `description:"活动时间"`
	ActivityTimeText        string `description:"活动时间带文字"`
	City                    string `description:"城市"`
	Address                 string `description:"活动地址"`
	DistinguishedGuest      string `description:"嘉宾"`
	Expert                  string `description:"专家"`
	IsSignup                int    `description:"是否已报名 1是 ，0 否"`
	SignupNum               int    `description:"已报名人数"`
	ActiveState             string `description:"活动进行状态 未开始：1、进行中2、已结束3"`
	IsCancelMeetingReminder int    `description:"是否取消会议提醒 1展示取消会议提醒 ，0展示会议提醒"`
	IsBrackets              int    `description:"是否有方括号 1是 ，0 否"`
	OpenId                  string `description:"OenId"`
	FailType                int    `description:"失败原因，0，未失败，1总人数已满，2单机构超限制，3，爽约次数超限"`
}

//列表 3o分钟
func GetActivitySendMsgListAll(endDate string) (items []*WxMsgCygxActivityList, err error) {
	o := orm.NewOrm()
	sql := `SELECT
	s.id,
	s.fail_type,
	cr.open_id,
	a.*
FROM
	cygx_activity AS a
	INNER JOIN cygx_activity_signup AS s ON s.activity_id = a.activity_id
	INNER   JOIN user_record AS c ON c.bind_account = s.mobile 
	INNER JOIN cygx_user_record AS cr ON cr.union_id = c.union_id 
WHERE
	1 = 1 
	AND s.is_send_wx_msg = 0 
	AND s.do_fail_type = 0 
	AND a.publish_status = 1 
	AND c.create_platform = 4
	AND a.activity_time <= ? AND a.activity_time >= NOW() 
	AND s.is_cancel = 0
	AND( a.activity_type_id IN (4,5,6) OR (a.activity_type_id = 3 AND a.is_limit_people = 1 )) 	GROUP BY s.id`
	_, err = o.Raw(sql, endDate).QueryRows(&items)
	return
}

//列表 15分钟提醒
func GetActivitySendMsgListAllMeeting(endDate string) (items []*WxMsgCygxActivityList, err error) {
	o := orm.NewOrm()
	sql := `SELECT
	m.id,
	cr.open_id,
	a.* 
FROM
	cygx_activity AS a
	INNER JOIN cygx_activity_meeting_reminder AS m ON m.activity_id = a.activity_id
	INNER JOIN user_record AS c ON c.bind_account = m.mobile 
	INNER JOIN cygx_user_record AS cr ON cr.union_id = c.union_id 
WHERE
	1 = 1 
	AND m.is_send_wx_msg = 0 
	AND a.publish_status = 1 
	AND a.activity_time <= ? AND a.activity_time >= NOW() 
	AND m.is_cancel = 0 
	AND c.create_platform = 4
	AND (
	a.activity_type_id IN ( 1, 2 ) 
	OR ( a.activity_type_id = 3 AND a.is_limit_people = 0 ))
	GROUP BY m.id`
	_, err = o.Raw(sql, endDate).QueryRows(&items)
	return
}

//修改是否推送消息状态
func UPdateSendedMsgStatus(signupIds string) (err error) {
	sql := ` UPDATE cygx_activity_signup SET  is_send_wx_msg= 1  WHERE id IN(` + signupIds + `)`
	o := orm.NewOrm()
	_, err = o.Raw(sql).Exec()
	return
}

//修改是否推送消息状态
func UPdateSendedMsgMeetingStatus(signupIds string) (err error) {
	sql := ` UPDATE cygx_activity_meeting_reminder SET  is_send_wx_msg= 1  WHERE id IN(` + signupIds + `)`
	o := orm.NewOrm()
	_, err = o.Raw(sql).Exec()
	return
}

//获取满足推送的活动ID数量
func GetCountActivityIdToSendFile(endDate string) (count int, err error) {
	o := orm.NewOrm()
	sql := `SELECT
	COUNT(1) count
FROM
	cygx_activity AS a
	INNER JOIN cygx_activity_signup AS s ON s.activity_id = a.activity_id 
WHERE
	1 = 1 
	AND s.signup_type = 1 
	AND s.fail_type = 0 
	AND a.is_send_file_toemail = 0 
	AND a.activity_time <= ? AND a.activity_time >= NOW() 	GROUP BY a.activity_id `
	err = o.Raw(sql, endDate).QueryRow(&count)
	return
}

//获取满足推送的活动ID
func GetActivityIdToSendFile(endDate string) (items []*ActivityIdRep, err error) {
	o := orm.NewOrm()
	sql := `SELECT
	* 
FROM
	cygx_activity AS a
	INNER JOIN cygx_activity_signup AS s ON s.activity_id = a.activity_id 
WHERE
	1 = 1 
	AND s.signup_type = 1 
	AND s.fail_type = 0 
	AND a.is_send_file_toemail = 0 
	AND a.activity_time <= ? AND a.activity_time >= NOW() 	GROUP BY a.activity_id `
	_, err = o.Raw(sql, endDate).QueryRows(&items)
	return
}

type SignupExportRep struct {
	Mobile         string `description:"手机号"`
	CompanyName    string `description:"公司名称"`
	RealName       string `description:"姓名"`
	CountryCode    string `description:"区号"`
	OutboundMobile string `description:"外呼手机号"`
	SellerName     string `description:"销售姓名"`
}

type ActivityMsgExportRep struct {
	RealName    string `description:"姓名"`
	CompanyName string `description:"公司名称"`
	Content     string `description:"内容"`
	CreateTime  string `description:"提交时间"`
}

func GetSignupExport(activityId int) (item []*SignupExportRep, err error) {
	o := orm.NewOrm()
	sql := `SELECT s.*  ,a.is_limit_people,u.real_name,
			(SELECT p.seller_name from company_product as p WHERE p.company_id = u.company_id  AND  p.product_id = 2 )  AS seller_name
			FROM
			cygx_activity_signup AS s
			LEFT JOIN wx_user AS u ON u.user_id = s.user_id
			LEFT JOIN cygx_activity AS a ON a.activity_id = s.activity_id
			LEFT JOIN company_product AS p ON p.company_id = u.company_id 
			WHERE a.activity_id = ?  AND s.do_fail_type = 0 AND s.signup_type = 1  GROUP BY s.id `
	_, err = o.Raw(sql, activityId).QueryRows(&item)
	return
}

//修改文件是否推送状态
func UPdateActivityIdToSendFile(activityId int) (err error) {
	sql := ` UPDATE cygx_activity SET  is_send_file_toemail= 1  WHERE activity_id = ?`
	o := orm.NewOrm()
	_, err = o.Raw(sql, activityId).Exec()
	return
}

//活动详情
type CygxActivityLabelList struct {
	KeyWord     string `orm:"column(label)";description:"主题"`
	Timesort    string `description:"最大时间"`
	Mintimesort string `description:"最小时间"`
	ImgUrlBg    string `description:"背景图片"`
}

//主题列表
func GetActivityLabelListAll(condition, sortTime string, pars []interface{}, startSize, pageSize int) (items []*CygxActivityLabelList, err error) {
	o := orm.NewOrm()
	sql := `SELECT	label, MAX( art.activity_time ) AS timesort, MIn( art.activity_time ) AS mintimesort 
		FROM cygx_activity as art WHERE 1= 1 `
	if condition != "" {
		sql += condition
	}
	sql += ` GROUP BY art.label ORDER BY ` + sortTime + ` ,art.activity_id DESC  LIMIT ?,? `

	_, err = o.Raw(sql, pars, startSize, pageSize).QueryRows(&items)
	return
}

type GetCygxActivityLabelListRep struct {
	Label  string `description:"主题"`
	ImgUrl string `description:"图片路径"`
	List   []*CygxActivityLabelList
}

//获取研选系列专家电话会，会前1小时，满足推送的活动ID数量
func GetCountActivityResearchToSendFile(condition, endDate string) (count int, err error) {
	o := orm.NewOrm()
	sql := `SELECT
	COUNT(1) count
FROM
	cygx_activity AS a
	INNER JOIN cygx_activity_help_ask AS k ON k.activity_id = a.activity_id 
WHERE
	1 = 1 ` + condition + `
	AND a.is_send_ask_msg = 0 
	AND a.activity_time <= ? 
	AND a.activity_time >= NOW()`
	err = o.Raw(sql, endDate).QueryRow(&count)
	return
}

//获取研选系列专家电话会，会前1小时，满足推送的活动ID
func GetActivityResearchToSendFile(condition, endDate string) (items []*ActivityIdRep, err error) {
	o := orm.NewOrm()
	sql := `SELECT
	* 
FROM
	cygx_activity AS a
	INNER JOIN cygx_activity_help_ask AS k ON k.activity_id = a.activity_id 
WHERE
	1 = 1 ` + condition + `
	AND a.is_send_ask_msg = 0 
	AND a.activity_time <= ? 
	AND a.activity_time >= NOW() 
GROUP BY
	a.activity_id `
	_, err = o.Raw(sql, endDate).QueryRows(&items)
	return
}

func GetActivityMsgExport(activityId int) (item []*ActivityMsgExportRep, err error) {
	o := orm.NewOrm()
	sql := `SELECT
			k.*,
			u.real_name 
			FROM
			cygx_activity_help_ask AS k
			LEFT JOIN wx_user AS u ON u.user_id = k.user_id 
			WHERE
			k.activity_id = ? 
			GROUP BY
			k.ask_id`
	_, err = o.Raw(sql, activityId).QueryRows(&item)
	return
}

//修改文件带问消息是否推送状态
func UPdateActivityMsgToSendFile(activityId int) (err error) {
	sql := ` UPDATE cygx_activity SET  is_send_ask_msg= 1  WHERE activity_id = ?`
	o := orm.NewOrm()
	_, err = o.Raw(sql, activityId).Exec()
	return
}

type AskEmailRep struct {
	Name  string `description:"姓名"`
	Email string `description:"邮箱"`
}

func GetAskEmail() (item []*AskEmailRep, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_activity_ask_email`
	_, err = o.Raw(sql).QueryRows(&item)
	return
}
