package models

import (
	"fmt"
	"github.com/rdlucklib/rdluck_tools/orm"
	"time"
)

//报名
type CygxActivityMeetDetailLog struct {
	AttendanceId int       `orm:"column(attendance_id);pk;"description:"主键ID"`
	ActivityId   int       `description:"活动ID"`
	RealName     string    `description:"姓名"`
	Mobile       string    `description:"手机号"`
	CompanyName  string    `description:"公司名称"`
	CompanyId    int       `description:"公司id 不在数据库的用户为0"`
	CreateTime   time.Time `description:"创建时间"`
}

func GetOfflineMeetingDetailListCompanyIdStr(companyIdStr string) (item []*CygxActivityMeetDetailLog, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_activity_offline_meeting_detail WHERE company_id IN (` + companyIdStr + `)`
	_, err = o.Raw(sql).QueryRows(&item)
	return
}

func GetOfflineMeetingDetailListCompanyName(companyName string) (item []*CygxActivityMeetDetailLog, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM cygx_activity_meet_detail_log WHERE company_name IN (` + companyName + `)`
	_, err = o.Raw(sql).QueryRows(&item)
	return
}

//添加
func AddCygxActivityMeetDetailLog(item *CygxActivityMeetDetailLog) (lastId int64, err error) {
	o := orm.NewOrm()
	lastId, err = o.Insert(item)
	return
}

func GetActivityMeetDetailLog(mobileStr string) (item []*CygxActivityMeetDetailLog, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM  cygx_activity_meet_detail_log WHERE mobile IN (` + mobileStr + `)`
	_, err = o.Raw(sql).QueryRows(&item)
	return
}

func GetActivityMeetDetailLogByMobile() (item []*CygxActivityMeetDetailLog, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM  cygx_activity_meet_detail_log WHERE mobile !='' GROUP BY mobile `
	_, err = o.Raw(sql).QueryRows(&item)
	return
}

//获取数量
func GetActivityMeetDetailLogCount(condition string) (count int, err error) {
	o := orm.NewOrm()
	sqlCount := ` SELECT COUNT(1) AS count  FROM cygx_activity_meet_detail_log WHERE 1=1 `
	if condition != "" {
		sqlCount += condition
	}
	err = o.Raw(sqlCount).QueryRow(&count)
	return
}

//修改公司参会数量
func UpdateActivityMeetDetailLog(companyName string, num int) (err error) {
	sql := ` UPDATE cygx_activity_meet_detail_log SET  company_meet_num= ?  WHERE company_name = ?`
	o := orm.NewOrm()
	_, err = o.Raw(sql, num, companyName).Exec()
	return
}

//修改个人参会数量
func UpdateActivityMeetDetailLogByUser(mobile string, num int) (err error) {
	sql := ` UPDATE cygx_activity_meet_detail_log SET  user_meet_num= ?  WHERE mobile = ?`
	o := orm.NewOrm()
	_, err = o.Raw(sql, num, mobile).Exec()
	return
}

//添加线上到会记录
func AddCygxActivityMeetDetailLogOnline(list []*CygxActivityAttendanceDetail, activityId int) (err error) {
	o := orm.NewOrm()
	o.Begin()
	defer func() {
		fmt.Println(err)
		if err == nil {
			o.Commit()
		} else {
			o.Rollback()
		}
	}()
	var CompanyName string
	var MobileStr string
	var items []*CygxActivityMeetDetailLog
	//删除原有数据
	sql := ` DELETE FROM cygx_activity_meet_detail_log WHERE activity_id = ?`
	_, err = o.Raw(sql, activityId).Exec()
	if err != nil {
		return
	}
	//插入新的数据
	for _, v := range list {
		item := new(CygxActivityMeetDetailLog)
		item.ActivityId = v.ActivityId
		item.Mobile = v.Mobile
		item.CompanyName = v.CompanyName
		item.CompanyId = v.CompanyId
		item.CreateTime = v.CreateTime
		CompanyName += "'" + v.CompanyName + "',"
		MobileStr += v.Mobile + ","
		items = append(items, item)
	}
	CompanyName = strings.TrimRight(CompanyName, ",")
	MobileStr = strings.TrimRight(MobileStr, ",")
	for _, v := range items {
		_, err = o.Insert(v)
		if err != nil {
			return
		}
	}
	listCompany, err := GetOfflineMeetingDetailListCompanyName(CompanyName)
	if err != nil {
		return
	}
	//修改公司对应的数量
	var condition string
	for _, v := range listCompany {
		var total int
		condition = ` AND company_name = '` + v.CompanyName + `' `
		total, err = GetActivityMeetDetailLogCount(condition)
		if err != nil {
			return
		}
		sql := ` UPDATE cygx_activity_meet_detail_log SET  company_meet_num= ?  WHERE company_name = ?`
		_, err = o.Raw(sql, total, v.CompanyName).Exec()
		if err != nil {
			return
		}
	}
	listMobile, err := GetActivityMeetDetailLog(MobileStr)
	if err != nil {
		return
	}
	//修改个人对应的数量
	for _, v := range listMobile {
		var total int
		condition = ` AND mobile = '` + v.Mobile + `' `
		total, err = GetActivityMeetDetailLogCount(condition)
		if err != nil {
			return
		}
		sql := ` UPDATE cygx_activity_meet_detail_log SET  user_meet_num= ?  WHERE mobile = ?`
		_, err = o.Raw(sql, total, v.Mobile).Exec()
		if err != nil {
			return
		}
	}
	return
}
