package models

import "github.com/rdlucklib/rdluck_tools/orm"

type CompanyDetail struct {
	CompanyId   int    `orm:"column(company_id);pk"`
	CompanyName string `description:"客户名称"`
	Status      string `description:"客户状态"`
	SellerId    int    `description:"销售id"`
	SellerName  string `description:"销售名称"`
	Mobile      string `description:"销售手机号"`
}

func GetCompanyDetailById(companyId int) (item *CompanyDetail, err error) {
	//sql := ` SELECT a.company_id,a.company_name,b.status,b.seller_id,b.seller_name,c.mobile
	//        FROM company AS a
	//		INNER JOIN company_product AS b ON a.company_id=b.company_id
	//		LEFT JOIN admin AS c ON b.seller_id=c.admin_id
	//		WHERE a.company_id=? AND  b.product_id=2 `

	sql := ` SELECT a.company_id,a.company_name,b.status,b.seller_id,b.seller_name,c.mobile 
            FROM company AS a
			INNER JOIN company_product AS b ON a.company_id=b.company_id
			INNER JOIN company_report_permission AS p ON p.company_id = a.company_id
			INNER JOIN chart_permission AS cp ON cp.chart_permission_id=p.chart_permission_id
			LEFT JOIN admin AS c ON b.seller_id=c.admin_id
			WHERE a.company_id=? AND cp.cygx_auth=1
			OR (a.company_id = ? AND  cp.permission_name = '策略' ) ORDER BY  b.product_id  DESC LIMIT 1` // 兼容永续状态
	o := orm.NewOrm()
	err = o.Raw(sql, companyId, companyId).QueryRow(&item)
	return
}

func GetCompanyDetailByIdGroup(companyId int) (item *CompanyDetail, err error) {
	sql := ` SELECT a.company_id,a.company_name,b.status,b.seller_id,b.seller_name,c.mobile 
            FROM company AS a
			INNER JOIN company_product AS b ON a.company_id=b.company_id
			INNER JOIN company_report_permission AS p ON p.company_id = a.company_id
			INNER JOIN chart_permission AS cp ON cp.chart_permission_id = p.chart_permission_id
			LEFT JOIN admin AS c ON b.seller_id=c.admin_id
			WHERE a.company_id=? AND b.product_id = 2 
			OR (a.company_id = ? AND  cp.permission_name = '策略' ) 
			ORDER BY b.product_id DESC  LIMIT 0,1 `
	o := orm.NewOrm()
	err = o.Raw(sql, companyId, companyId).QueryRow(&item)
	return
}

func GetCountCompanyDetailByIdGroup(companyId int) (count int, err error) {
	sql := ` SELECT COUNT(1) AS count
            FROM company AS a
			INNER JOIN company_product AS b ON a.company_id=b.company_id
			INNER JOIN company_report_permission AS p ON p.company_id = a.company_id
			INNER JOIN chart_permission AS cp ON cp.chart_permission_id = p.chart_permission_id
			LEFT JOIN admin AS c ON b.seller_id=c.admin_id
			WHERE a.company_id=? AND b.product_id = 2   OR (a.company_id = ? AND  cp.permission_name = '策略' )   `
	o := orm.NewOrm()
	err = o.Raw(sql, companyId, companyId).QueryRow(&count)
	return
}

//原有权限叫校验，下方更改与2021-5.18
//func GetCompanyPermission(companyId int) (permission string, err error) {
//	sql := ` SELECT GROUP_CONCAT(DISTINCT b.chart_permission_name  ORDER BY b.sort ASC SEPARATOR ',') AS permission
//			FROM company_report_permission AS a
//			INNER JOIN chart_permission AS b ON a.chart_permission_id=b.chart_permission_id
//			INNER JOIN company_product AS c ON a.company_id=c.company_id AND a.product_id=c.product_id
//			WHERE  a.company_id=?
//			AND a.product_id=2
//            AND b.show_type=1
//			AND c.status IN('正式','试用','永续') `
//	o := orm.NewOrm()
//	err = o.Raw(sql, companyId).QueryRow(&permission)
//	return
//}

func GetCompanyPermission(companyId int) (permission string, err error) {
	sql := ` SELECT GROUP_CONCAT(DISTINCT b.chart_permission_name  ORDER BY b.sort ASC SEPARATOR ',') AS permission
			FROM company_report_permission AS a
			INNER JOIN chart_permission AS b ON a.chart_permission_id=b.chart_permission_id
			INNER JOIN company_product AS c ON a.company_id=c.company_id AND a.product_id=c.product_id
			WHERE  a.company_id=?
			AND c.is_suspend=0
            AND b.cygx_auth=1
			AND c.status IN('正式','试用','永续')
			AND a.status IN('正式','试用','永续') `
	o := orm.NewOrm()
	err = o.Raw(sql, companyId).QueryRow(&permission)
	return
}

func GetCompanyPermissionByName(name string) (permission string, err error) {
	sql := ` SELECT GROUP_CONCAT(DISTINCT b.chart_permission_name  ORDER BY b.sort ASC SEPARATOR '/') AS permission
			FROM company_report_permission AS a
			INNER JOIN chart_permission AS b ON a.chart_permission_id=b.chart_permission_id
			INNER JOIN company_product AS c ON a.company_id=c.company_id AND a.product_id=c.product_id
			INNER JOIN company AS cm ON cm.company_id=c.company_id 
			WHERE  cm.company_name=?
			AND b.product_id = 2 `
	o := orm.NewOrm()
	err = o.Raw(sql, name).QueryRow(&permission)
	return
}

func GetCompanyDetailAllById(companyId int) (item *CompanyDetail, err error) {
	sql := ` SELECT a.company_id,a.company_name,b.status,b.seller_id,b.seller_name,c.mobile 
            FROM company AS a
			INNER JOIN company_product AS b ON a.company_id=b.company_id
			INNER JOIN company_report_permission AS p ON p.company_id = a.company_id
			INNER JOIN chart_permission AS cp ON cp.chart_permission_id=p.chart_permission_id
			LEFT JOIN admin AS c ON b.seller_id=c.admin_id
			WHERE a.company_id=? AND cp.cygx_auth=1
			OR (a.company_id = ? AND  cp.permission_name = '策略' )` // 兼容永续状态
	//WHERE a.company_id=?  AND b.status IN('正式','试用','永续')`
	o := orm.NewOrm()
	err = o.Raw(sql, companyId, companyId).QueryRow(&item)
	return
}

//获取对应销售以及销售的手机号
func GetSellerDetailAllByCompanyId(companyId int) (item *CompanyDetail, err error) {
	sql := ` SELECT c.mobile ,c.real_name as seller_name
			FROM
			company AS a
			INNER JOIN company_product AS b ON a.company_id = b.company_id
			INNER JOIN admin AS c ON b.seller_id = c.admin_id 
			WHERE
			b.product_id = 2 
			AND a.company_id = ? LIMIT 1`
	o := orm.NewOrm()
	err = o.Raw(sql, companyId).QueryRow(&item)
	return
}

func GetCompanySellerName(companyId int) (sellerName string, err error) {
	sql := ` SELECT
			GROUP_CONCAT( DISTINCT p.seller_name SEPARATOR '/' ) AS sellerName 
		FROM
			company_product AS p
		WHERE
			p.company_id = ? `
	o := orm.NewOrm()
	err = o.Raw(sql, companyId).QueryRow(&sellerName)
	return
}
