package services

import (
	"context"
	"fmt"
	"github.com/tealeg/xlsx"
	"hongze/hongze_cygx/models"
	"hongze/hongze_cygx/utils"
	"os"
	"path/filepath"
	"strconv"
	"strings"
	"time"
)

//修改活动状态
func UpdateActivitySattus(cont context.Context) (err error) {
	defer func() {
		if err != nil {
			fmt.Println("同步失败，Err:", err.Error())
		}
	}()
	go models.UpdateActivitySattusToHaveInHand()
	go models.UpdateActivitySattusToComplete()
	return
}

//推送会议开始消息提醒60分钟前
func SendActivityBeginMsg(cont context.Context) (err error) {
	defer func() {
		if err != nil {
			fmt.Println("发送失败，Err:", err.Error())
		}
	}()
	endDate := time.Now().Add(+time.Minute * 60).Format(utils.FormatDateTime)
	listActivity, err := models.GetActivitySendMsgListAll(endDate)
	fmt.Println(len(listActivity))
	if err != nil {
		fmt.Println("GetActivitySendMsgListAll Err:", err.Error())
		return
	}
	if len(listActivity) == 0 {
		return
	}
	var remark = "点击查看活动详情"
	var signupIds string
	for _, v := range listActivity {
		signupIds += strconv.Itoa(v.Id) + ","
		var reserveResults string
		var first string
		openIdItem := new(models.OpenIdList)
		openIdItem.OpenId = v.OpenId
		openIdList := make([]*models.OpenIdList, 0)
		openIdList = append(openIdList, openIdItem)
		if v.FailType == 0 {
			reserveResults = "成功"
		} else if v.FailType == 1 {
			reserveResults = "失败（总人数已满）"
		} else if v.FailType == 2 {
			reserveResults = "失败（单机构超限制）"
		} else if v.FailType == 3 {
			reserveResults = "失败（爽约次数超限）"
		}
		first = "您有一场【" + v.ActivityTypeName + "】将在1小时后开始"
		SendWxMsgWithFrequency(first, v.ActivityName, reserveResults, v.ActivityTime, v.Address, remark, openIdList, v.ActivityId)
	}
	if len(signupIds) == 0 {
		return
	}
	signupIds = strings.TrimRight(signupIds, ",")
	err = models.UPdateSendedMsgStatus(signupIds)
	if err != nil {
		var msg string
		go utils.SendEmail("发送模版消息失败"+"【"+utils.APPNAME+"】"+time.Now().Format(utils.FormatDateTime), msg+";Err:"+err.Error(), utils.EmailSendToUsers)
		utils.FileLog.Info("发送模版消息失败,Err:%s", err.Error())
	}
	return
}

//推送会议开始消息提醒15分钟前
func SendActivityBeginMsgMeeting(cont context.Context) (err error) {
	defer func() {
		if err != nil {
			fmt.Println("发送失败，Err:", err.Error())
		}
	}()
	endDate := time.Now().Add(+time.Minute * 15).Format(utils.FormatDateTime)
	listActivity, err := models.GetActivitySendMsgListAllMeeting(endDate)
	if err != nil {
		fmt.Println("GetActivitySendMsgListAll Err:", err.Error())
		return
	}
	if len(listActivity) == 0 {
		return
	}
	var signupIds string
	var remark = "点击查看活动详情"
	for _, v := range listActivity {
		signupIds += strconv.Itoa(v.Id) + ","
		var reserveResults string
		var first string
		openIdItem := new(models.OpenIdList)
		openIdItem.OpenId = v.OpenId
		openIdList := make([]*models.OpenIdList, 0)
		openIdList = append(openIdList, openIdItem)
		reserveResults = "--"
		first = "您有一场【" + v.ActivityTypeName + "】将在15分钟后开始"
		SendWxMsgWithFrequency(first, v.ActivityName, reserveResults, v.ActivityTime, "--", remark, openIdList, v.ActivityId)
	}
	if len(signupIds) == 0 {
		return
	}
	signupIds = strings.TrimRight(signupIds, ",")
	err = models.UPdateSendedMsgMeetingStatus(signupIds)
	if err != nil {
		var msg string
		go utils.SendEmail("发送模版消息失败"+"【"+utils.APPNAME+"】"+time.Now().Format(utils.FormatDateTime), msg+";Err:"+err.Error(), utils.EmailSendToUsers)
		utils.FileLog.Info("发送模版消息失败,Err:%s", err.Error())
	}
	return
}

//预约外呼名单，会前1小时自动发送邮件给专家组
func SendEmailFileToExpert(cont context.Context) (err error) {
	var msg string
	var touser string
	defer func() {
		if err != nil {
			fmt.Println("err：", err)
			go utils.SendEmail("发送附件模版消息失败"+"【"+utils.APPNAME+"】"+time.Now().Format(utils.FormatDateTime), msg+";Err:"+err.Error(), utils.EmailSendToUsers)
			utils.FileLog.Info("发送附件模版消息失败,Err:%s", err.Error())
		}
		if msg != "" {
			fmt.Println(msg)
			utils.FileLog.Info("发送模版消息失败,msg:%s", msg)
		}
	}()
	endDate := time.Now().Add(+time.Minute * 60).Format(utils.FormatDateTime)
	total, err := models.GetCountActivityIdToSendFile(endDate)

	if total == 0 {
		fmt.Println("发送附件完成0")
		return nil
	}
	if err != nil {
		msg = "发送附件模版消息失败 Err:" + err.Error()
		return
	}
	listActivity, err := models.GetActivityIdToSendFile(endDate)
	if err != nil {
		msg = "发送附件模版消息失败 Err:" + err.Error()
		return
	}

	for _, v := range listActivity {
		activityInfo, _ := models.GetAddActivityInfoById(v.ActivityId)
		if activityInfo == nil {
			msg = "活动不存在，Err:activityId：" + strconv.Itoa(v.ActivityId)
			return
		}
		list, errFile := models.GetSignupExport(v.ActivityId)
		if errFile != nil {
			msg = "获取失败，Err:" + errFile.Error()
			return
		}
		//创建excel
		dir, errFile := os.Executable()
		exPath := filepath.Dir(dir)
		downLoadnFilePath := exPath + "/" + time.Now().Format(utils.FormatDateTimeUnSpace) + utils.GetRandDigit(5) + ".xlsx"
		xlsxFile := xlsx.NewFile()
		if errFile != nil {
			msg = "生成文件失败Err:" + errFile.Error()
			return
		}
		style := xlsx.NewStyle()
		alignment := xlsx.Alignment{
			Horizontal: "center",
			Vertical:   "center",
			WrapText:   true,
		}
		style.Alignment = alignment
		style.ApplyAlignment = true
		sheet, errFile := xlsxFile.AddSheet("外呼名单")
		if errFile != nil {
			msg = "新增Sheet失败,Err:" + errFile.Error()
			return
		}
		//设置宽度
		_ = sheet.SetColWidth(1, 1, 15)
		_ = sheet.SetColWidth(3, 3, 30)
		//标头
		rowTitle := sheet.AddRow()
		cellA := rowTitle.AddCell()
		cellA.Value = "姓名"
		cellB := rowTitle.AddCell()
		cellB.Value = "外呼号码"
		cellC := rowTitle.AddCell()
		cellC.Value = "国际代码"
		cellD := rowTitle.AddCell()
		cellD.Value = "公司名称"
		cellE := rowTitle.AddCell()
		cellE.Value = "所属销售"

		for _, item := range list {
			row := sheet.AddRow()
			cellA := row.AddCell()
			cellA.Value = item.RealName
			cellB := row.AddCell()
			cellB.Value = item.OutboundMobile
			cellC := row.AddCell()
			if item.CountryCode == "" {
				cellC.Value = "86"
			} else {
				cellC.Value = item.CountryCode
			}
			cellD := row.AddCell()
			cellD.Value = item.CompanyName
			cellE := row.AddCell()
			cellE.Value = item.SellerName
		}
		errFile = xlsxFile.Save(downLoadnFilePath)
		if errFile != nil {
			msg = "保存文件失败Err:" + errFile.Error()
			return
		}
		title := activityInfo.ActivityName + "外呼名单"
		content := "外呼名单详情"
		fileName := downLoadnFilePath
		if activityInfo.ChartPermissionName == "科技" || activityInfo.ChartPermissionNames == "研选(科技)" {
			touser = utils.EmailTechnology
		} else if activityInfo.ChartPermissionName == "医药" || activityInfo.ChartPermissionNames == "研选(医药)" {
			touser = utils.EmailMedicine
		} else if activityInfo.ChartPermissionName == "消费" || activityInfo.ChartPermissionNames == "研选(消费)" {
			touser = utils.EmailConsumption
		} else if activityInfo.ChartPermissionName == "智造" || activityInfo.ChartPermissionNames == "研选(智造)" {
			touser = utils.EmailZhizao
		} else if activityInfo.ChartPermissionName == "策略" || activityInfo.ChartPermissionNames == "研选" {
			touser = utils.EmailStrategy
		}
		sendResult := utils.SendEmailByHongze(title, content, touser, fileName, title+".xlsx")
		if sendResult {
			errFile = models.UPdateActivityIdToSendFile(v.ActivityId)
			if errFile != nil {
				msg = "获取失败，Err:" + errFile.Error()
				return
			}
			os.Remove(downLoadnFilePath)
		} else {
			go utils.SendEmail("发送附件模版消息失败"+"【"+utils.APPNAME+"】"+time.Now().Format(utils.FormatDateTime), msg+";Err:"+activityInfo.ActivityName, utils.EmailSendToUsers)
			utils.FileLog.Info("发送附件模版消息失败,Err:%s", activityInfo.ActivityName)
		}
	}
	return
}

func EditOutboundMobile(cont context.Context) (err error) {
	defer func() {
		if err != nil {
			fmt.Println("发送失败，Err:", err.Error())
		}
	}()

	list, err := models.GetActivitySignupListAll()
	if err != nil {
		fmt.Println("GetActivitySendMsgListAll Err:", err.Error())
		return
	}
	for _, v := range list {
		err = models.UPdateSignup(v)
		fmt.Println("修改:", strconv.Itoa(v.Id))
		if err != nil {
			fmt.Println("发送失败，Err:", err.Error()+strconv.Itoa(v.Id))
		}
	}
	fmt.Println("修改完成")
	return
}

//同步用户绑定手机号以及区号
func EditUserOutboundMobile(cont context.Context) (err error) {
	defer func() {
		if err != nil {
			fmt.Println("发送失败，Err:", err.Error())
		}
	}()

	list, err := models.GetUserListAll()
	if err != nil {
		fmt.Println("GetActivitySendMsgListAll Err:", err.Error())
		return
	}
	for _, v := range list {
		err = models.UPdateUserCountryCode(v)
		fmt.Println("修改:", strconv.Itoa(v.UserId))
		if err != nil {
			fmt.Println("发送失败，Err:", err.Error()+strconv.Itoa(v.UserId))
		}
	}
	fmt.Println("修改完成")
	return
}

//获取 用户类型   //1、永续客户 //2、大套餐客户（4个行业全开通的正式客户） //3、分行业套餐客户（开通对应行业的正式客户） //4、仅开通专家套餐的正式客户 //5、开通对应行业套餐或专家套餐的试用客户
func GetUserType(companyId int) (userType int, permissionStrnew string, err error) {

	var permissionStr string
	if companyId <= 1 {
		userType = 0
	} else {
		total, errs := models.GetCountCompanyDetailByIdGroup(companyId)
		if errs != nil {
			err = errs
			return
		}
		if total == 0 {
			userType = 0
		} else {
			companyDetail, errs := models.GetCompanyDetailByIdGroup(companyId)
			if errs != nil {
				err = errs
				return
			}
			permissionStr, errs = models.GetCompanyPermission(companyId)
			if errs != nil {
				err = errs
				return
			}
			//1、永续客户 //2、大套餐客户（4个行业全开通的正式客户） //3、分行业套餐客户（开通对应行业的正式客户） //4、仅开通专家套餐的正式客户 //5、开通对应行业套餐或专家套餐的试用客户
			if companyDetail.Status == "永续" {
				userType = 1
			} else if companyDetail.Status == "试用" {
				userType = 5
			} else if companyDetail.Status == "正式" {
				if permissionStr == "专家" {
					userType = 4
				} else if strings.Contains(permissionStr, "医药") && strings.Contains(permissionStr, "消费") && strings.Contains(permissionStr, "科技") && strings.Contains(permissionStr, "智造") {
					userType = 2
				} else {
					userType = 3
				}
				if userType == 3 {
					if !strings.Contains(permissionStr, "医药") && !strings.Contains(permissionStr, "消费") && !strings.Contains(permissionStr, "科技") && !strings.Contains(permissionStr, "智造") {
						userType = 4
					}
				}
			}
		}
	}
	permissionStrnew = permissionStr
	return
}

// 校验被分享的用户是否有查看详情的权限
func GetShareNoPowe(activityInfo *models.ActivityDetail, permissionStr string, userType int) (noPower bool, err error) {
	//var noPower bool
	if (userType == 1 || userType == 4 || userType == 5) && !strings.Contains(activityInfo.CustomerTypeIds, strconv.Itoa(userType)) {
		noPower = true
	}
	//1、永续客户 //2、大套餐客户（4个行业全开通的正式客户） //3、分行业套餐客户（开通对应行业的正式客户） //4、仅开通专家套餐的正式客户 //5、开通对应行业套餐或专家套餐的试用客户
	if userType == 2 && strings.Contains(permissionStr, "专家") && !strings.Contains(activityInfo.CustomerTypeIds, strconv.Itoa(2)) && !strings.Contains(activityInfo.CustomerTypeIds, strconv.Itoa(3)) && !strings.Contains(activityInfo.CustomerTypeIds, strconv.Itoa(4)) {
		noPower = true
	}
	if userType == 2 && !strings.Contains(permissionStr, "专家") && !strings.Contains(activityInfo.CustomerTypeIds, strconv.Itoa(2)) && !strings.Contains(activityInfo.CustomerTypeIds, strconv.Itoa(3)) {
		noPower = true
	}
	if userType == 3 && strings.Contains(permissionStr, "专家") && !strings.Contains(activityInfo.CustomerTypeIds, strconv.Itoa(3)) && !strings.Contains(activityInfo.CustomerTypeIds, strconv.Itoa(4)) {
		noPower = true
	}
	if userType == 3 && !strings.Contains(permissionStr, "专家") && !strings.Contains(activityInfo.CustomerTypeIds, strconv.Itoa(3)) {
		noPower = true
	}
	return
}

// 校验用户报名的权限
func GetHavePower(activityInfo *models.ActivityDetail, permissionStr, companyDetailStatus string, userType int) (havePower bool, err error) {
	if (activityInfo.ActivityTypeId == 1 || activityInfo.ActivityTypeId == 3) && strings.Contains(permissionStr, "专家") && activityInfo.LimitPeopleNum == 0 {
		havePower = true
	} else if activityInfo.ActivityTypeId == 3 && strings.Contains(permissionStr, "专家") && companyDetailStatus == "正式" && strings.Contains(activityInfo.CustomerTypeIds, "4") {
		havePower = true
	} else if activityInfo.ActivityTypeId == 3 && strings.Contains(permissionStr, "专家") && companyDetailStatus == "试用" && strings.Contains(activityInfo.CustomerTypeIds, "5") {
		havePower = true
	} else if strings.Contains(permissionStr, activityInfo.ChartPermissionName) && strings.Contains(activityInfo.CustomerTypeIds, strconv.Itoa(userType)) {
		havePower = true
	} else if strings.Contains(permissionStr, activityInfo.ChartPermissionName) {
		havePower = true
	} else if activityInfo.ActivityTypeId == 5 && strings.Contains(permissionStr, "专家") {
		havePower = true
	}
	return
}

//研选系列专家电话会，会前1小时将问题列表发送给邮箱
func SendEmailFileForAskMsgResearch(cont context.Context) (err error) {
	var msg string
	var touser string
	defer func() {
		if err != nil {
			fmt.Println("err：", err)
			go utils.SendEmail("发送附件模版消息失败"+"【"+utils.APPNAME+"】"+time.Now().Format(utils.FormatDateTime), msg+";Err:"+err.Error(), utils.EmailSendToUsers)
			utils.FileLog.Info("发送附件模版消息失败,Err:%s", err.Error())
		}
		if msg != "" {
			fmt.Println(msg)
			utils.FileLog.Info("发送模版消息失败,msg:%s", msg)
		}
	}()
	endDate := time.Now().Add(+time.Minute * 60).Format(utils.FormatDateTime)
	condition := `AND  a.activity_type_id = 1 AND a.chart_permission_name = '研选' `
	total, err := models.GetCountActivityResearchToSendFile(condition, endDate)
	if total == 0 {
		fmt.Println("发送附件完成0")
		return nil
	}
	if err != nil {
		msg = "发送附件模版消息失败 Err:" + err.Error()
		return
	}
	listActivity, err := models.GetActivityResearchToSendFile(condition, endDate)
	if err != nil {
		msg = "发送附件模版消息失败 Err:" + err.Error()
		return
	}
	for _, v := range listActivity {
		activityInfo, _ := models.GetAddActivityInfoById(v.ActivityId)
		if activityInfo == nil {
			msg = "活动不存在，Err:activityId：" + strconv.Itoa(v.ActivityId)
			return
		}
		list, errFile := models.GetActivityMsgExport(v.ActivityId)
		if errFile != nil {
			msg = "获取失败，Err:" + errFile.Error()
			return
		}
		//创建excel
		dir, errFile := os.Executable()
		exPath := filepath.Dir(dir)
		downLoadnFilePath := exPath + "/" + time.Now().Format(utils.FormatDateTimeUnSpace) + utils.GetRandDigit(5) + ".xlsx"
		xlsxFile := xlsx.NewFile()
		if errFile != nil {
			msg = "生成文件失败Err:" + errFile.Error()
			return
		}
		style := xlsx.NewStyle()
		alignment := xlsx.Alignment{
			Horizontal: "center",
			Vertical:   "center",
			WrapText:   true,
		}
		style.Alignment = alignment
		style.ApplyAlignment = true
		sheet, errFile := xlsxFile.AddSheet("外呼名单")
		if errFile != nil {
			msg = "新增Sheet失败,Err:" + errFile.Error()
			return
		}
		//设置宽度
		_ = sheet.SetColWidth(1, 1, 30)
		_ = sheet.SetColWidth(2, 2, 60)
		//标头
		rowTitle := sheet.AddRow()
		cellA := rowTitle.AddCell()
		cellA.Value = "姓名"
		cellB := rowTitle.AddCell()
		cellB.Value = "公司名称"
		cellC := rowTitle.AddCell()
		cellC.Value = "问题"
		cellD := rowTitle.AddCell()
		cellD.Value = "提交时间"

		for _, item := range list {
			row := sheet.AddRow()
			cellA := row.AddCell()
			cellA.Value = item.RealName
			cellB := row.AddCell()
			cellB.Value = item.CompanyName
			cellC := row.AddCell()
			cellC.Value = item.Content
			cellD := row.AddCell()
			cellD.Value = item.CreateTime
		}
		errFile = xlsxFile.Save(downLoadnFilePath)
		if errFile != nil {
			msg = "保存文件失败Err:" + errFile.Error()
			return
		}
		title := activityInfo.ActivityName + "-活动带问"
		content := "活动带问详情"
		fileName := downLoadnFilePath
		if utils.RunMode == "release" {
			touser = "cxzhang@hzinsights.com;ywang@hzinsights.com;tshen@hzinsights.com"
		} else {
			touser = "cxzhang@hzinsights.com;jhwang@hzinsights.com;tshen@hzinsights.com"
		}
		sendResult := utils.SendEmailByHongze(title, content, touser, fileName, title+".xlsx")
		if sendResult {
			errFile = models.UPdateActivityMsgToSendFile(v.ActivityId)
			if errFile != nil {
				msg = "获取失败，Err:" + errFile.Error()
				return
			}
			os.Remove(downLoadnFilePath)
		} else {
			go utils.SendEmail("发送附件模版消息失败"+"【"+utils.APPNAME+"】"+time.Now().Format(utils.RunMode), msg+";Err:"+activityInfo.ActivityName, utils.EmailSendToUsers)
			utils.FileLog.Info("发送附件模版消息失败,Err:%s", activityInfo.ActivityName)
		}
	}
	return
}

//非研选系列专家电话会，根据主持人姓名，会前15分钟将问题列表发送给至该主持人对应邮箱
func SendEmailFileForAskMsg(cont context.Context) (err error) {
	var msg string
	var touser string
	defer func() {
		if err != nil {
			go utils.SendEmail("发送附件模版消息失败"+"【"+utils.APPNAME+"】"+time.Now().Format(utils.FormatDateTime), msg+";Err:"+err.Error(), utils.EmailSendToUsers)
			utils.FileLog.Info("发送附件模版消息失败,Err:%s", err.Error())
		}
		if msg != "" {
			utils.FileLog.Info("发送模版消息失败,msg:%s", msg)
		}
	}()
	endDate := time.Now().Add(+time.Minute * 15).Format(utils.FormatDateTime)
	condition := `AND  a.activity_type_id = 1 AND  a.chart_permission_name != '研选' `
	total, err := models.GetCountActivityResearchToSendFile(condition, endDate)
	if total == 0 {
		fmt.Println("发送附件完成0")
		return nil
	}
	if err != nil {
		msg = "发送附件模版消息失败 Err:" + err.Error()
		return
	}
	listActivity, err := models.GetActivityResearchToSendFile(condition, endDate)
	if err != nil {
		msg = "发送附件模版消息失败 Err:" + err.Error()
		return
	}
	listEmail, errEmail := models.GetAskEmail()
	if errEmail != nil {
		msg = "获取失败，Err:" + errEmail.Error()
		return
	}
	for _, v := range listActivity {
		activityInfo, _ := models.GetAddActivityInfoById(v.ActivityId)
		if activityInfo == nil {
			msg = "活动不存在，Err:activityId：" + strconv.Itoa(v.ActivityId)
			return
		}
		list, errFile := models.GetActivityMsgExport(v.ActivityId)
		if errFile != nil {
			msg = "获取失败，Err:" + errFile.Error()
			return
		}
		for _, v := range listEmail {
			if strings.Index(activityInfo.Host, v.Name) > 0 {
				touser += v.Email + ";"
			}
		}
		if touser == "" {
			msg = "没有对应的邮箱"
			return
		}
		if utils.RunMode == "release" {
			touser += "tshen@hzinsights.com;cxzhang@hzinsights.com"
		} else {
			touser = "tshen@hzinsights.com;cxzhang@hzinsights.com"
		}

		//创建excel
		dir, errFile := os.Executable()
		exPath := filepath.Dir(dir)
		downLoadnFilePath := exPath + "/" + time.Now().Format(utils.FormatDateTimeUnSpace) + utils.GetRandDigit(5) + ".xlsx"
		xlsxFile := xlsx.NewFile()
		if errFile != nil {
			msg = "生成文件失败Err:" + errFile.Error()
			return
		}
		style := xlsx.NewStyle()
		alignment := xlsx.Alignment{
			Horizontal: "center",
			Vertical:   "center",
			WrapText:   true,
		}
		style.Alignment = alignment
		style.ApplyAlignment = true
		sheet, errFile := xlsxFile.AddSheet("外呼名单")
		if errFile != nil {
			msg = "新增Sheet失败,Err:" + errFile.Error()
			return
		}
		//设置宽度
		_ = sheet.SetColWidth(1, 1, 30)
		_ = sheet.SetColWidth(2, 2, 60)
		//标头
		rowTitle := sheet.AddRow()
		cellA := rowTitle.AddCell()
		cellA.Value = "姓名"
		cellB := rowTitle.AddCell()
		cellB.Value = "公司名称"
		cellC := rowTitle.AddCell()
		cellC.Value = "问题"
		cellD := rowTitle.AddCell()
		cellD.Value = "提交时间"
		for _, item := range list {
			row := sheet.AddRow()
			cellA := row.AddCell()
			cellA.Value = item.RealName
			cellB := row.AddCell()
			cellB.Value = item.CompanyName
			cellC := row.AddCell()
			cellC.Value = item.Content
			cellD := row.AddCell()
			cellD.Value = item.CreateTime
		}
		errFile = xlsxFile.Save(downLoadnFilePath)
		if errFile != nil {
			msg = "保存文件失败Err:" + errFile.Error()
			return
		}
		title := activityInfo.ActivityName + "-活动带问"
		content := "活动带问详情"
		fileName := downLoadnFilePath
		sendResult := utils.SendEmailByHongze(title, content, touser, fileName, title+".xlsx")
		if sendResult {
			errFile = models.UPdateActivityMsgToSendFile(v.ActivityId)
			if errFile != nil {
				msg = "获取失败，Err:" + errFile.Error()
				return
			}
			os.Remove(downLoadnFilePath)
		} else {
			go utils.SendEmail("发送附件模版消息失败"+"【"+utils.APPNAME+"】"+time.Now().Format(utils.FormatDateTime), msg+";Err:"+activityInfo.ActivityName, utils.EmailSendToUsers)
			utils.FileLog.Info("发送附件模版消息失败,Err:%s", activityInfo.ActivityName)
		}
	}
	return
}

//活动标签字符串处理
func LabelStr(label string) (labelNew string) {
	slicebr := strings.Split(label, "-")
	if len(slicebr) < 2 {
		labelNew = label
	} else {
		labelNew = slicebr[1]
	}
	return labelNew
}

func ActivityAttendanceDetail() {
	var mobileStr string
	fmt.Println("开始同步")
	dateTime := time.Now().AddDate(0, 0, -2).Format(utils.FormatDate)
	startDate := dateTime + " 00:00:00"
	endDate := dateTime + " 23:59:59"
	//获取需要处理的活动
	listActivity, err := models.GetActivityListByDateTime(startDate, endDate)
	if err != nil {
		fmt.Println("GetTacticsList Err:", err.Error())
		return
	}
	for _, vAct := range listActivity {
		doTime := utils.TimeRemoveHms2(vAct.ActivityTime)
		findStartDate := doTime + " 00:00:00"
		findEndDate := doTime + " 23:59:59"
		nameSlice := strings.Split(vAct.ActivityName, "】")
		//fmt.Println(timeSlice[0])
		var activityName string
		if len(nameSlice) > 1 {
			activityName = nameSlice[len(nameSlice)-1]
			if activityName != "" {
				list, err := models.GetRoadshowDataList(activityName, findStartDate, findEndDate)
				if err != nil {
					fmt.Println("GetTacticsList Err:", err.Error())
					return
				}
				needAddAttendanc := make([]*models.CygxActivityAttendanceDetail, 0)
				fmt.Println("原来的", vAct.ActivityName)
				fmt.Println("处理的", activityName)
				if len(list) > 0 {
					for _, v := range list {
						if v.UserPhone != "" {
							item := new(models.CygxActivityAttendanceDetail)
							item.ActivityId = vAct.ActivityId
							item.RealName = v.UserName
							item.Mobile = v.UserPhone
							item.CompanyName = v.Company
							//item.SellerName = sellerName
							item.FirstMeetingTime = v.FirstWatchTime
							item.LastMeetingTime = v.LastWatchTime
							item.Duration = utils.GetAttendanceDetailSeconds(v.JoinTime)
							if v.JoinType == 1 {
								item.MeetingTypeStr = "网络"
							} else {
								item.MeetingTypeStr = "电话"
							}
							item.MeetingAuthentication = v.AuthInfo
							if v.DataType == 1 {
								item.MeetingStatusStr = "直播"
							} else {
								item.MeetingStatusStr = "回放"
							}
							item.Position = v.Occupation
							item.CreateTime = time.Now()
							mobileStr += "'" + v.UserPhone + "'" + ","
							needAddAttendanc = append(needAddAttendanc, item)
						}
					}
					mobileStr = strings.TrimRight(mobileStr, ",")
					if mobileStr == "" {
						mobileStr = "1"
					}
					listUser, err := models.GetWxUserOutboundMobile(mobileStr)
					if err != nil {
						fmt.Println("GetWxUserOutboundMobile Err:", err.Error())
						return
					}
					for k, v := range needAddAttendanc {
						for _, v2 := range listUser {
							if v2.OutboundMobile == v.Mobile {
								needAddAttendanc[k].CompanyId = v2.CompanyId
								needAddAttendanc[k].SellerName = v2.SellerName
								needAddAttendanc[k].CompanyName = v2.CompanyName
								needAddAttendanc[k].IsMeetingStr = 1
							}
						}
					}
					fmt.Println(mobileStr)
					err = models.AddAttendancDetail(needAddAttendanc, vAct.ActivityId, mobileStr)
					if err != nil {
						fmt.Println("AddAttendancDetail Err:", err.Error())
						return
					}
					go AddCygxActivityRestrictSignupByAdmin(vAct.ActivityId)
					err = models.AddCygxActivityMeetDetailLogOnline(needAddAttendanc, vAct.ActivityId)
					fmt.Println(err)
				}
			}
		}
	}
	fmt.Println("结束同步")
}

func AddCygxActivityRestrictSignupByAdmin(activityId int) {
	var msg string
	total, err := models.GetActivitySignupNomeetingCount(activityId)
	fmt.Println(total)
	if err != nil {
		utils.FileLog.Info("用户限制报名失败,Err:%s,%s", err.Error(), msg)
		fmt.Println(" Err:", err.Error())
	}
	mobileList, _ := models.GetUserMeetingMobile(activityId)
	if len(mobileList) >= 0 {
		for _, v := range mobileList {
			totalRestrict, err := models.GetRestrictSignupCountByUid(v.UserId)
			if err != nil {
				fmt.Println(" Err:", err.Error())
				utils.FileLog.Info("用户限制报名失败,Err:%s,%s", err.Error(), msg)
			}
			totalNomeet, err := models.GetActivitySignupNomeetingCountByUid(v.UserId)
			if err != nil {
				fmt.Println(" Err:", err.Error())
				utils.FileLog.Info("用户限制报名失败,Err:%s,%s", err.Error(), msg)
			}
			if totalRestrict > 0 && totalNomeet < 3 {
				err = models.DeleteCygxActivityRestrictSignup(v.UserId)
				if err != nil {
					fmt.Println(" Err:", err.Error())
					utils.FileLog.Info("用户限制报名失败,Err:%s,%s", err.Error(), msg)
				}
			}
		}
	}

	if total == 0 {
		return
	}
	list, err := models.GetActivitySignupNomeetingCountList(activityId)
	fmt.Println(list)
	if err != nil {
		utils.FileLog.Info("用户限制报名失败,Err:%s,%s", err.Error(), msg)
		fmt.Println(" 用户限制报名失败 Err:", err.Error())
	}
	for _, v := range list {
		totalRestrict, err := models.GetRestrictSignupCountByUid(v.UserId)
		if err != nil {
			fmt.Println(" Err:", err.Error())
			utils.FileLog.Info("用户限制报名失败,Err:%s,%s", err.Error(), msg)
		}
		totalNomeet, err := models.GetActivitySignupNomeetingCountByUid(v.UserId)
		if err != nil {
			fmt.Println(" Err:", err.Error())
			utils.FileLog.Info("用户限制报名失败,Err:%s,%s", err.Error(), msg)
		}
		if totalNomeet >= 3 {
			if totalRestrict == 0 {
				infoUser, err := models.GetUserAndCompanyNameList(v.UserId)
				if err != nil {
					fmt.Println(" Err:", err.Error())
				}
				if infoUser != nil {
					item := new(models.CygxActivityRestrictSignup)
					item.UserId = infoUser.UserId
					item.CreateTime = time.Now()
					item.Mobile = infoUser.Mobile
					item.Email = infoUser.Email
					item.CompanyId = infoUser.CompanyId
					item.CompanyName = infoUser.CompanyName
					item.IsRestrict = 1
					err = models.AddCygxActivityRestrictSignup(item)
					if err != nil {
						fmt.Println(" Err:", err.Error())
					}
				}
			}
		}
	}
}
